@@ -9,7 +9,7 @@ require Exporter;
 
 use vars qw($VERSION @ISA @EXPORT);
 
-$VERSION=0.02;
+$VERSION=0.03;
 
 @ISA = qw(Exporter);
 @EXPORT = qw(&rsh);
@@ -39,9 +39,11 @@ sub rsh {
                                 		Proto=>"tcp");
 
 		if(!defined $socket) {
-        		if($!{EADDRINUSE}) {
+        		if ($!{EADDRINUSE} || $!{ECONNREFUSED}) {
                 		$port-=1;
-        		} else {croak $!;}
+        		} else {
+                                croak("$!");
+                        }
 		} else { $try=0; }
 	}                                                                                                                                  
 
